@@ -7,7 +7,7 @@ package IO::Async::TimeQueue;
 
 use strict;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Carp;
 
@@ -91,22 +91,12 @@ The C<%params> takes the following keys:
 
 The absolute system timestamp to run the event.
 
-=item delay => NUM
-
-The delay after now at which to run the event.
-
-=item now => NUM
-
-The time to consider as now; defaults to C<time()> if not specified.
-
 =item code => CODE
 
 CODE reference to the callback function to run at the allotted time.
 
 =back
 
-Either C<time> or C<delay> must be specified.
-
 =cut
 
 sub enqueue
@@ -114,22 +104,12 @@ sub enqueue
    my $self = shift;
    my ( %params ) = @_;
 
-   my $time;
-   if( exists $params{time} ) {
-      $time = delete $params{time};
-   }
-   elsif( exists $params{delay} ) {
-      my $now = exists $params{now} ? $params{now} : time();
-
-      $time = $now + delete $params{delay};
-   }
-   else {
-      croak "Expected either 'time' or 'delay' keys";
-   }
-
    my $code = delete $params{code};
    ref $code eq "CODE" or croak "Expected 'code' to be a CODE reference";
 
+   defined $params{time} or croak "Expected 'time'";
+   my $time = $params{time};
+
    my $heap = $self->{heap};
 
    my $elem = IO::Async::TimeQueue::Elem->new( $time, $code );
@@ -153,6 +133,39 @@ sub cancel
    $heap->delete( $id );
 }
 
+=head2 $newid = $queue->requeue( $id, %params )
+
+Reschedule an existing timer, moving it to a new time. The old timer is
+removed and will not be invoked.
+
+The C<%params> hash takes the same keys as C<enqueue()>, except for the
+C<code> argument.
+
+The requeue operation may be implemented as a cancel + enqueue, which may
+mean the ID changes. Be sure to store the returned C<$newid> value if it is
+required.
+
+=cut
+
+sub requeue
+{
+   my $self = shift;
+   my ( $id, %params ) = @_;
+
+   defined $params{time} or croak "Expected 'time'";
+   my $time = $params{time};
+
+   my $heap = $self->{heap};
+   my $elem = $heap->delete( $id );
+   defined $elem or croak "No such enqueued timer";
+
+   $elem->time( $time );
+
+   $heap->add( $elem );
+
+   return $elem;
+}
+
 =head2 $count = $queue->fire( %params )
 
 Call all the event callbacks that should have run by now. The number of
